@@ -1,6 +1,6 @@
 package Pithub::Gists::Comments;
 BEGIN {
-  $Pithub::Gists::Comments::VERSION = '0.01001';
+  $Pithub::Gists::Comments::VERSION = '0.01002';
 }
 
 # ABSTRACT: Github v3 Gist Comments API
@@ -15,28 +15,28 @@ sub create {
     my ( $self, %args ) = @_;
     croak 'Missing key in parameters: gist_id' unless $args{gist_id};
     croak 'Missing key in parameters: data (hashref)' unless ref $args{data} eq 'HASH';
-    return $self->request( POST => sprintf( '/gists/%d/comments', $args{gist_id} ), $args{data} );
+    return $self->request( POST => sprintf( '/gists/%s/comments', $args{gist_id} ), $args{data} );
 }
 
 
 sub delete {
     my ( $self, %args ) = @_;
     croak 'Missing key in parameters: comment_id' unless $args{comment_id};
-    return $self->request( DELETE => sprintf( '/gists/comments/%d', $args{comment_id} ) );
+    return $self->request( DELETE => sprintf( '/gists/comments/%s', $args{comment_id} ) );
 }
 
 
 sub get {
     my ( $self, %args ) = @_;
     croak 'Missing key in parameters: comment_id' unless $args{comment_id};
-    return $self->request( GET => sprintf( '/gists/comments/%d', $args{comment_id} ) );
+    return $self->request( GET => sprintf( '/gists/comments/%s', $args{comment_id} ) );
 }
 
 
 sub list {
     my ( $self, %args ) = @_;
     croak 'Missing key in parameters: gist_id' unless $args{gist_id};
-    return $self->request( GET => sprintf( '/gists/%d/comments', $args{gist_id} ) );
+    return $self->request( GET => sprintf( '/gists/%s/comments', $args{gist_id} ) );
 }
 
 
@@ -44,7 +44,7 @@ sub update {
     my ( $self, %args ) = @_;
     croak 'Missing key in parameters: comment_id' unless $args{comment_id};
     croak 'Missing key in parameters: data (hashref)' unless ref $args{data} eq 'HASH';
-    return $self->request( PATCH => sprintf( '/gists/comments/%d', $args{comment_id} ), $args{data} );
+    return $self->request( PATCH => sprintf( '/gists/comments/%s', $args{comment_id} ), $args{data} );
 }
 
 __PACKAGE__->meta->make_immutable;
@@ -60,7 +60,7 @@ Pithub::Gists::Comments - Github v3 Gist Comments API
 
 =head1 VERSION
 
-version 0.01001
+version 0.01002
 
 =head1 METHODS
 
@@ -74,8 +74,6 @@ Create a comment
 
     POST /gists/:gist_id/comments
 
-=back
-
 Examples:
 
     $result = $p->gists->comments->create(
@@ -83,6 +81,8 @@ Examples:
         data    => { body => 'some comment' },
     );
 
+=back
+
 =head2 delete
 
 =over
@@ -93,12 +93,12 @@ Delete a comment
 
     DELETE /gists/comments/:id
 
-=back
-
 Examples:
 
     $result = $p->gists->comments->delete( comment_id => 1 );
 
+=back
+
 =head2 get
 
 =over
@@ -109,12 +109,12 @@ Get a single comment
 
     GET /gists/comments/:id
 
-=back
-
 Examples:
 
     $result = $p->gists->comments->get( comment_id => 1 );
 
+=back
+
 =head2 list
 
 =over
@@ -125,12 +125,12 @@ List comments on a gist
 
     GET /gists/:gist_id/comments
 
-=back
-
 Examples:
 
     $result = $p->gists->comments->list( gist_id => 1 );
 
+=back
+
 =head2 update
 
 =over
@@ -141,8 +141,6 @@ Edit a comment
 
     PATCH /gists/comments/:id
 
-=back
-
 Examples:
 
     $result = $p->gists->comments->update(
@@ -150,6 +148,8 @@ Examples:
         data       => { body => 'some comment' }
     );
 
+=back
+
 =head1 AUTHOR
 
 Johannes Plunien <plu@cpan.org>
