@@ -1,6 +1,6 @@
 package Pithub::Issues::Events;
 BEGIN {
-  $Pithub::Issues::Events::VERSION = '0.01001';
+  $Pithub::Issues::Events::VERSION = '0.01002';
 }
 
 # ABSTRACT: Github v3 Issue Events API
@@ -15,7 +15,7 @@ sub get {
     my ( $self, %args ) = @_;
     croak 'Missing key in parameters: event_id' unless $args{event_id};
     $self->_validate_user_repo_args( \%args );
-    return $self->request( GET => sprintf( '/repos/%s/%s/issues/events/%d', $args{user}, $args{repo}, $args{event_id} ) );
+    return $self->request( GET => sprintf( '/repos/%s/%s/issues/events/%s', $args{user}, $args{repo}, $args{event_id} ) );
 }
 
 
@@ -23,7 +23,7 @@ sub list {
     my ( $self, %args ) = @_;
     $self->_validate_user_repo_args( \%args );
     if ( my $issue_id = $args{issue_id} ) {
-        return $self->request( GET => sprintf( '/repos/%s/%s/issues/%d/events', $args{user}, $args{repo}, $issue_id ) );
+        return $self->request( GET => sprintf( '/repos/%s/%s/issues/%s/events', $args{user}, $args{repo}, $issue_id ) );
     }
     return $self->request( GET => sprintf( '/repos/%s/%s/issues/events', $args{user}, $args{repo} ) );
 }
@@ -41,7 +41,7 @@ Pithub::Issues::Events - Github v3 Issue Events API
 
 =head1 VERSION
 
-version 0.01001
+version 0.01002
 
 =head1 METHODS
 
@@ -55,8 +55,6 @@ Get a single event
 
     GET /repos/:user/:repo/issues/events/:id
 
-=back
-
 Examples:
 
     $result = $p->issues->events->get(
@@ -65,6 +63,8 @@ Examples:
         event_id => 1,
     );
 
+=back
+
 =head2 list
 
 =over
@@ -89,13 +89,15 @@ List events for a repository
 
     GET /repos/:user/:repo/issues/events
 
-=back
+Examples:
 
     $result = $p->issues->events->list(
         repo => 'Pithub',
         user => 'plu',
     );
 
+=back
+
 =head1 AUTHOR
 
 Johannes Plunien <plu@cpan.org>
