@@ -1,6 +1,6 @@
 package Pithub::Orgs::Teams;
 BEGIN {
-  $Pithub::Orgs::Teams::VERSION = '0.01001';
+  $Pithub::Orgs::Teams::VERSION = '0.01002';
 }
 
 # ABSTRACT: Github v3 Org Teams API
@@ -15,7 +15,7 @@ sub add_member {
     my ( $self, %args ) = @_;
     croak 'Missing key in parameters: team_id' unless $args{team_id};
     croak 'Missing key in parameters: user'    unless $args{user};
-    return $self->request( PUT => sprintf( '/teams/%d/members/%s', $args{team_id}, $args{user} ) );
+    return $self->request( PUT => sprintf( '/teams/%s/members/%s', $args{team_id}, $args{user} ) );
 }
 
 
@@ -23,7 +23,7 @@ sub add_repo {
     my ( $self, %args ) = @_;
     croak 'Missing key in parameters: team_id' unless $args{team_id};
     croak 'Missing key in parameters: repo'    unless $args{repo};
-    return $self->request( PUT => sprintf( '/teams/%d/repos/%s', $args{team_id}, $args{repo} ) );
+    return $self->request( PUT => sprintf( '/teams/%s/repos/%s', $args{team_id}, $args{repo} ) );
 }
 
 
@@ -38,14 +38,14 @@ sub create {
 sub delete {
     my ( $self, %args ) = @_;
     croak 'Missing key in parameters: team_id' unless $args{team_id};
-    return $self->request( DELETE => sprintf( '/teams/%d', $args{team_id} ) );
+    return $self->request( DELETE => sprintf( '/teams/%s', $args{team_id} ) );
 }
 
 
 sub get {
     my ( $self, %args ) = @_;
     croak 'Missing key in parameters: team_id' unless $args{team_id};
-    return $self->request( GET => sprintf( '/teams/%d', $args{team_id} ) );
+    return $self->request( GET => sprintf( '/teams/%s', $args{team_id} ) );
 }
 
 
@@ -53,7 +53,7 @@ sub get_repo {
     my ( $self, %args ) = @_;
     croak 'Missing key in parameters: team_id' unless $args{team_id};
     croak 'Missing key in parameters: repo'    unless $args{repo};
-    return $self->request( GET => sprintf( '/teams/%d/repos/%s', $args{team_id}, $args{repo} ) );
+    return $self->request( GET => sprintf( '/teams/%s/repos/%s', $args{team_id}, $args{repo} ) );
 }
 
 
@@ -61,7 +61,7 @@ sub is_member {
     my ( $self, %args ) = @_;
     croak 'Missing key in parameters: team_id' unless $args{team_id};
     croak 'Missing key in parameters: user'    unless $args{user};
-    return $self->request( GET => sprintf( '/teams/%d/members/%s', $args{team_id}, $args{user} ) );
+    return $self->request( GET => sprintf( '/teams/%s/members/%s', $args{team_id}, $args{user} ) );
 }
 
 
@@ -75,14 +75,14 @@ sub list {
 sub list_members {
     my ( $self, %args ) = @_;
     croak 'Missing key in parameters: team_id' unless $args{team_id};
-    return $self->request( GET => sprintf( '/teams/%d/members', $args{team_id} ) );
+    return $self->request( GET => sprintf( '/teams/%s/members', $args{team_id} ) );
 }
 
 
 sub list_repos {
     my ( $self, %args ) = @_;
     croak 'Missing key in parameters: team_id' unless $args{team_id};
-    return $self->request( GET => sprintf( '/teams/%d/repos', $args{team_id} ) );
+    return $self->request( GET => sprintf( '/teams/%s/repos', $args{team_id} ) );
 }
 
 
@@ -90,7 +90,7 @@ sub remove_member {
     my ( $self, %args ) = @_;
     croak 'Missing key in parameters: team_id' unless $args{team_id};
     croak 'Missing key in parameters: user'    unless $args{user};
-    return $self->request( DELETE => sprintf( '/teams/%d/members/%s', $args{team_id}, $args{user} ) );
+    return $self->request( DELETE => sprintf( '/teams/%s/members/%s', $args{team_id}, $args{user} ) );
 }
 
 
@@ -98,7 +98,7 @@ sub remove_repo {
     my ( $self, %args ) = @_;
     croak 'Missing key in parameters: team_id' unless $args{team_id};
     croak 'Missing key in parameters: repo'    unless $args{repo};
-    return $self->request( DELETE => sprintf( '/teams/%d/repos/%s', $args{team_id}, $args{repo} ) );
+    return $self->request( DELETE => sprintf( '/teams/%s/repos/%s', $args{team_id}, $args{repo} ) );
 }
 
 
@@ -106,7 +106,7 @@ sub update {
     my ( $self, %args ) = @_;
     croak 'Missing key in parameters: team_id' unless $args{team_id};
     croak 'Missing key in parameters: data (hashref)' unless ref $args{data} eq 'HASH';
-    return $self->request( PATCH => sprintf( '/teams/%d', $args{team_id} ), $args{data} );
+    return $self->request( PATCH => sprintf( '/teams/%s', $args{team_id} ), $args{data} );
 }
 
 __PACKAGE__->meta->make_immutable;
@@ -122,7 +122,7 @@ Pithub::Orgs::Teams - Github v3 Org Teams API
 
 =head1 VERSION
 
-version 0.01001
+version 0.01002
 
 =head1 METHODS
 
@@ -136,8 +136,6 @@ team is associated with.
 
     PUT /teams/:id/members/:user
 
-=back
-
 Examples:
 
     $result = $p->orgs->teams->add_member(
@@ -145,6 +143,8 @@ Examples:
         user    => 'plu',
     );
 
+=back
+
 =head2 add_repo
 
 =over
@@ -154,8 +154,6 @@ an owner of the org that the team is associated with.
 
     PUT /teams/:id/repos/:repo
 
-=back
-
 Examples:
 
     $result = $p->orgs->teams->add_repo(
@@ -163,6 +161,8 @@ Examples:
         repo    => 'some_repo',
     );
 
+=back
+
 =head2 create
 
 =over
@@ -172,8 +172,6 @@ owner of the given organization.
 
     POST /orgs/:org/teams
 
-=back
-
 Examples:
 
     $result = $p->orgs->teams->create(
@@ -185,6 +183,8 @@ Examples:
         }
     );
 
+=back
+
 =head2 delete
 
 =over
@@ -194,12 +194,12 @@ of the org that the team is associated with.
 
     DELETE /teams/:id
 
-=back
-
 Examples:
 
     $result = $p->orgs->teams->delete( team_id => 1 );
 
+=back
+
 =head2 get
 
 =over
@@ -208,12 +208,12 @@ Get team
 
     GET /teams/:id
 
-=back
-
 Examples:
 
     $result = $p->orgs->teams->get( team_id => 1 );
 
+=back
+
 =head2 get_repo
 
 =over
@@ -222,8 +222,6 @@ Get team repo
 
     GET /teams/:id/repos/:repo
 
-=back
-
 Examples:
 
     $result = $p->orgs->teams->get_repo(
@@ -231,6 +229,8 @@ Examples:
         repo    => 'some_repo',
     );
 
+=back
+
 =head2 is_member
 
 =over
@@ -240,8 +240,6 @@ user must be a member of the team.
 
     GET /teams/:id/members/:user
 
-=back
-
 Examples:
 
     $result = $p->orgs->teams->is_member(
@@ -249,6 +247,8 @@ Examples:
         user    => 'plu',
     );
 
+=back
+
 =head2 list
 
 =over
@@ -257,12 +257,12 @@ List teams
 
     GET /orgs/:org/teams
 
-=back
-
 Examples:
 
     $result = $p->orgs->teams->list( org => 'CPAN-API' );
 
+=back
+
 =head2 list_members
 
 =over
@@ -272,12 +272,12 @@ a member of the team.
 
     GET /teams/:id/members
 
-=back
-
 Examples:
 
     $result = $p->orgs->teams->list_members( team_id => 1 );
 
+=back
+
 =head2 list_repos
 
 =over
@@ -286,12 +286,12 @@ List team repos
 
     GET /teams/:id/repos
 
-=back
-
 Examples:
 
     $result = $p->orgs->teams->list_repos( team_id => 1 );
 
+=back
+
 =head2 remove_member
 
 =over
@@ -303,8 +303,6 @@ it just remove them from the team.
 
     DELETE /teams/:id/members/:user
 
-=back
-
 Examples:
 
     $result = $p->orgs->teams->remove_member(
@@ -312,6 +310,8 @@ Examples:
         user    => 'plu',
     );
 
+=back
+
 =head2 remove_repo
 
 =over
@@ -321,8 +321,6 @@ an owner of the org that the team is associated with.
 
     DELETE /teams/:id/repos/:repo
 
-=back
-
 Examples:
 
     $result = $p->orgs->teams->remove_repo(
@@ -330,6 +328,8 @@ Examples:
         repo    => 'some_repo',
     );
 
+=back
+
 =head2 update
 
 =over
@@ -339,8 +339,6 @@ of the org that the team is associated with.
 
     PATCH /teams/:id
 
-=back
-
 Examples:
 
     $result = $p->orgs->teams->update(
@@ -351,6 +349,8 @@ Examples:
         }
     );
 
+=back
+
 =head1 AUTHOR
 
 Johannes Plunien <plu@cpan.org>
